PopupController class
Inheritance
Object
GetLifeCycle
DisposableInterface
GetxController
PopupController
Implemented types
Properties
captchaOpenedAt
↔ DateTime ?
getter/setter pair
captchaUrl
↔ RxString
getter/setter pair
deviceIp
↔ String
getter/setter pair
deviceName
↔ String
getter/setter pair
deviceType
↔ String
getter/setter pair
error
↔ RxString
getter/setter pair
hashCode
→ int
The hash code for this object.
no setter inherited
hasListeners
→ bool
no setter inherited
initialized
→ bool
Checks whether the controller has already been initialized.
no setter inherited
isClosed
→ bool
Checks whether the controller has already been closed.
no setter inherited
isLoading
↔ RxBool
getter/setter pair
isOtherLoading
↔ RxBool
getter/setter pair
isVerified
↔ RxBool
getter/setter pair
listeners
→ int
no setter inherited
onDelete
→ InternalFinalCallback<void >
Internal callback that starts the cycle of this controller.
final inherited
onStart
→ InternalFinalCallback<void >
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
timeSpentInSeconds
→ int
no setter
udid
↔ String
getter/setter pair
Methods
$configureLifeCycle ()
→ void
inherited
addListener (GetStateUpdate listener )
→ Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId (Object ? key , GetStateUpdate listener )
→ Disposer
inherited
dispose ()
→ void
inherited
disposeId (Object id )
→ void
To dispose an id from future updates(), this ids are registered
by GetBuilder() or similar, so is a way to unlink the state change with
the Widget from the Controller.
inherited
getCaptcha ({required double height , required double width , required String visiterId , required String requestId , required CyberSiaraModel cieraModel })
→ dynamic
Fetches a CAPTCHA challenge for user verification.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens ()
→ void
inherited
onClose ()
→ void
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
onInit ()
→ void
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
onReady ()
→ void
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
refresh ()
→ void
inherited
refreshGroup (Object id )
→ void
inherited
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
removeListenerId (Object id , VoidCallback listener )
→ void
inherited
startCaptchaTimer ()
→ void
submitCaptcha ({required String txt , required String requestId , required String visiterId , required CyberSiaraModel cieraModel })
→ Future <bool >
Submits the CAPTCHA response for verification.
toString ()
→ String
A string representation of this object.
inherited
update ([List <Object > ? ids , bool condition = true ])
→ void
Rebuilds GetBuilder each time you call update();
Can take a List of ids, that will only update the matching
GetBuilder( id: ),
ids can be reused among GetBuilders like group tags.
The update will only notify the Widgets, if condition is true.
inherited
validateToken (String bearerToken , CyberSiaraModel cieraModel )
→ Future <bool >
Validates the authentication token received from the API.
siarashield_flutter 0.0.11